==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>תמונות</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">פתיחת תיקייה</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>אין לך הרשאות לצפות בתמונה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">ביטול</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>סוג</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>מועד השינוי</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>גודל הקובץ</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>מצב חשיפה</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>תכנית חשיפה</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>זמן חשיפה</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>מבזק</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>צמצם</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>אורך מוקד</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>חשיפה</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>צמצם מרבי</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>איזון לבן</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>פיצוי מבזק</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>דגם העדשה</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>מרחב צבע</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>דגם המצלמה</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>בחירת תיקייה</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>הוספת תיקייה</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished">תמונות</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished">שינוי שם</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>Rename</source>
        <translation type="obsolete">שינוי שם</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation></translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation></translation>
    </message>
    <message>
        <source>Image info</source>
        <translation></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation></translation>
    </message>
    <message>
        <source>Next</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation></translation>
    </message>
</context>
</TS>
